#!/usr/bin/env python3
# -----------------------------------------------------------------
# Improved representation of clouds in the atmospheric component
# LMDZ6A of the IPSL Earth system model IPSL-CM6A
# J.-B. Madeleine et al. - 2020
# Journal of Advances in Modeling Earth Systems
# 
# Source Codes and supporting files
# Figure 9
# -----------------------------------------------------------------

from netCDF4 import Dataset as open_ncfile
import matplotlib.pyplot as plt
import numpy as np

nc = open_ncfile('data/LmdzOrAPctrl_SE_1980_1999_1M_histmth_light.nc')
lat = nc.variables['lat'][:]
lon = nc.variables['lon'][:]
lwp5A = nc.variables['lwp'][:]
iwp5A = nc.variables['iwp'][:]
foce5A = nc.variables['fract_oce'][:]
foce5A[foce5A != 1] = np.nan

nc = open_ncfile('data/LmdzOr6Actrl_SE_1980_1999_1M_histmth_light.nc')
lwp6A = nc.variables['lwp'][:]
iwp6A = nc.variables['iwp'][:]
foce6A = nc.variables['fract_oce'][:]
foce6A[foce6A != 1] = np.nan

lwp5A2 = lwp5A[0,:,:]*foce5A[0,:,:]
iwp5A2 = iwp5A[0,:,:]*foce5A[0,:,:]
lwp6A2 = lwp6A[0,:,:]*foce6A[0,:,:]
iwp6A2 = iwp6A[0,:,:]*foce6A[0,:,:]
for itime in range(1,lwp5A.shape[0]):
    lwp5Atmp = lwp5A[itime,:,:]*foce5A[itime,:,:]
    lwp5A2 = np.dstack((lwp5Atmp,lwp5A2))
    iwp5Atmp = iwp5A[itime,:,:]*foce5A[itime,:,:]
    iwp5A2 = np.dstack((iwp5Atmp,iwp5A2))
    lwp6Atmp = lwp6A[itime,:,:]*foce6A[itime,:,:]
    lwp6A2 = np.dstack((lwp6Atmp,lwp6A2))
    iwp6Atmp = iwp6A[itime,:,:]*foce6A[itime,:,:]
    iwp6A2 = np.dstack((iwp6Atmp,iwp6A2))
    
lwp5A = np.stack(np.stack(lwp5A2, axis=2),axis=2)
iwp5A = np.stack(np.stack(iwp5A2, axis=2),axis=2)
lwp6A = np.stack(np.stack(lwp6A2, axis=2),axis=2)
iwp6A = np.stack(np.stack(iwp6A2, axis=2),axis=2)

# ----------------------------------------------------------------------------

lwp5Am = np.nanmean(np.nanmean(lwp5A[:,:,:],axis=0),axis=1)
iwp5Am = np.nanmean(np.nanmean(iwp5A[:,:,:],axis=0),axis=1)

lwp6Am = np.nanmean(np.nanmean(lwp6A[:,:,:],axis=0),axis=1)
iwp6Am = np.nanmean(np.nanmean(iwp6A[:,:,:],axis=0),axis=1)

fig, ax = plt.subplots(2)

ax[0].plot(lat, lwp5Am*1E3, 'k', linewidth=2.0,linestyle='-',label='LWP')
ax[0].plot(lat, iwp5Am*1E3, '0.4', linewidth=2.0,linestyle='--',label='IWP')
ax[0].set_title("LMDZ5A")
ax[1].plot(lat, lwp6Am*1E3, 'k', linewidth=2.0,linestyle='-')
ax[1].plot(lat, iwp6Am*1E3, '0.4', linewidth=2.0,linestyle='--')
ax[1].set_title("LMDZ6A")

for ax in ax.flat:
    ax.set_ylabel(r"Water path (g/m$^2$)")
    ax.grid(linestyle='--', linewidth=1)
    ax.set_xlim(xmin=-80,xmax=80)
    ax.set_ylim(ymin=0,ymax=200)
    ax.set_xticks(np.round((np.arange(-80, 81, 20)), 2))


fig.legend(loc=(0.45, 0.78))
plt.xlabel(r"Latitude")
plt.show()

# ----------------------------------------------------------------------------
